==> charcoal-0.3.1.tar.gz: charcoal-0.3.1/web_app/06_form/classes/form_models/EntryFormModel.class.php <==
<?
class EntryFormModel extends charcoal_DefaultFormModel
{
	var $___form         = '@action:?proc=confirm @method:POST';

	var $___default_caption_class    = 'my_caption';
	var $___default_text_class       = 'my_input';
	var $___default_password_class   = 'my_input';
	var $___default_select_class     = 'my_input';
	var $___default_submit_class     = 'my_submit';
	var $___default_reset_class      = 'my_submit';

	var $input_panel_1   = '@class:hoge';
	var $input_panel_2   = '@class:hoge';
	var $input_panel_3   = '@class:hoge';
	var $input_panel_4   = '@class:hoge';
	var $input_panel_5   = '@class:hoge';
	var $input_panel_6   = '@class:hoge';
	var $input_panel_7   = '@class:hoge';
	var $input_panel_8   = '@class:hoge';
	var $button_panel    = '@style:width:300px;';

	var $first_name      = '@field @input @panel:input_panel_1 @input_type:text @size:40 @caption:Ļ @value:%DTO_VALUE%';
	var $account         = '@field @input @panel:input_panel_2 @input_type:text @size:20 @caption:  @value:%DTO_VALUE%';
	var $password        = '@field @input @panel:input_panel_3 @input_type:password @size:20 @caption:ѥ  @value:%DTO_VALUE%';
	var $sex             = '@field @input @panel:input_panel_4 @input_type:radio @choice_list:sex @checked:1 @caption:   @value:%DTO_VALUE%';
	var $age             = '@field @input @panel:input_panel_5 @input_type:radio @choice_list:age @checked:2 @caption:ǯ   @value:%DTO_VALUE%';
	var $area            = '@field @input @panel:input_panel_6 @input_type:select @choice_list:area @caption:ϰ   @value:%DTO_VALUE%';
	var $favorite        = '@field @input @panel:input_panel_7 @input_type:checkbox @choice_list:favorite @checked:1,4,5 @caption:   @value:%DTO_VALUE%';
	var $opinion         = '@field @input @panel:input_panel_8 @input_type:textarea @cols:50 @rows:10 @caption:ո   @value:%DTO_VALUE%';

	var $submit          = '@input @panel:button_panel @input_type:submit @value:';
	var $reset           = '@input @panel:button_panel @input_type:reset @value:ꥻå';

	/*
	 *   ꥹȤθ
	 */
	public function getChoiceList( $list_name )
	{
		switch ( $list_name ){
		case 'favorite':
			return array( 
						'0' => 'Ż', 
						'1' => '֥', 
						'2' => '', 
						'3' => '', 
						'4' => '', 
						'5' => '', 
						'6' => 'к', 
						'7' => 'ݡ', 
						'8' => 'եå', 
					);
		case 'area':
			return array( 
						'0' => '̳ƻ', 
						'1' => '', 
						'2' => '', 
						'3' => '', 
						'4' => 'ᵦ', 
						'5' => '͹', 
						'6' => '', 
						'7' => '彣', 
					);
		case 'age':
			return array( 
						'0' => '10', 
						'1' => '20', 
						'2' => '30', 
						'3' => '40', 
						'4' => '50', 
						'5' => '60', 
					);
		case 'sex':
			return array( '0' => '', '1' => '' );
		}

		return NULL;
	}

}

==> charcoal-0.3.2.tar.gz: charcoal-0.3.2/web_app/06_form/classes/form_models/EntryFormModel.class.php <==
<?
class EntryFormModel extends charcoal_DefaultFormModel
{
	var $___form         = '@action:?proc=confirm @method:POST';

	var $___default_caption_class    = 'my_caption';
	var $___default_text_class       = 'my_input';
	var $___default_password_class   = 'my_input';
	var $___default_select_class     = 'my_input';
	var $___default_submit_class     = 'my_submit';
	var $___default_reset_class      = 'my_submit';

	var $input_panel_1   = '@class:hoge';
	var $input_panel_2   = '@class:hoge';
	var $input_panel_3   = '@class:hoge';
	var $input_panel_4   = '@class:hoge';
	var $input_panel_5   = '@class:hoge';
	var $input_panel_6   = '@class:hoge';
	var $input_panel_7   = '@class:hoge';
	var $input_panel_8   = '@class:hoge';
	var $button_panel    = '@style:width:300px;';

	var $first_name      = '@field @input @panel:input_panel_1 @input_type:text @size:40 @caption:Ļ @value:%DTO_VALUE%';
	var $account         = '@field @input @panel:input_panel_2 @input_type:text @size:20 @caption:  @value:%DTO_VALUE%';
	var $password        = '@field @input @panel:input_panel_3 @input_type:password @size:20 @caption:ѥ  @value:%DTO_VALUE%';
	var $sex             = '@field @input @panel:input_panel_4 @input_type:radio @choice_list:sex @checked:1 @caption:   @value:%DTO_VALUE%';
	var $age             = '@field @input @panel:input_panel_5 @input_type:radio @choice_list:age @checked:2 @caption:ǯ   @value:%DTO_VALUE%';
	var $area            = '@field @input @panel:input_panel_6 @input_type:select @choice_list:area @caption:ϰ   @value:%DTO_VALUE%';
	var $favorite        = '@field @input @panel:input_panel_7 @input_type:checkbox @choice_list:favorite @checked:1,4,5 @caption:   @value:%DTO_VALUE%';
	var $opinion         = '@field @input @panel:input_panel_8 @input_type:textarea @cols:50 @rows:10 @caption:ո   @value:%DTO_VALUE%';

	var $submit          = '@input @panel:button_panel @input_type:submit @value:';
	var $reset           = '@input @panel:button_panel @input_type:reset @value:ꥻå';

	/*
	 *   ꥹȤθ
	 */
	public function getChoiceList( charcoal_ProcedureContext $context, $list_name )
	{
		switch ( $list_name ){
		case 'favorite':
			return array( 
						'0' => 'Ż', 
						'1' => '֥', 
						'2' => '', 
						'3' => '', 
						'4' => '', 
						'5' => '', 
						'6' => 'к', 
						'7' => 'ݡ', 
						'8' => 'եå', 
					);
		case 'area':
			return array( 
						'0' => '̳ƻ', 
						'1' => '', 
						'2' => '', 
						'3' => '', 
						'4' => 'ᵦ', 
						'5' => '͹', 
						'6' => '', 
						'7' => '彣', 
					);
		case 'age':
			return array( 
						'0' => '10', 
						'1' => '20', 
						'2' => '30', 
						'3' => '40', 
						'4' => '50', 
						'5' => '60', 
					);
		case 'sex':
			return array( '0' => '', '1' => '' );
		}

		return NULL;
	}

}
